#!/bin/bash

export DISPLAY=:0

case "$1" in
    on)
        echo "on 0" | cec-client -s
        sleep 5
        echo "as" | cec-client -s
        /opt/vc/bin/tvservice -p || echo "no tvservice"
        xset dpms force on
    ;;
    off)
        /opt/vc/bin/tvservice -o || echo "no tvservice"
        echo "standby 0" | cec-client -s
        xset dpms force off
    ;;
    state)
        tvstate=`/opt/vc/bin/tvservice -s 2>&1`
        if [[ $? != 0 ]] || [[ $tvstate == *"Failed to connect"* ]] ; then
            echo 'unavailable'
        elif [[ $tvstate == *"off"* ]] ; then
            echo 'off'
        else
            echo 'on'
        fi
    ;;
    subscribe)
        /opt/vc/bin/tvservice -M
    ;;
    screens)
        xrandr | awk '/ connected/{print $1}'
    ;;
    displays)
        ps -u $(id -u) -o pid= | \
            while read pid; do
                cat /proc/$pid/environ 2>/dev/null | tr '\0' '\n' | grep '^DISPLAY=:'
            done | grep -o ':[0-9]*' | sort -u
    ;;
    screenshot)
         if [ "$BOARD_ID" = 'rpi' ]; then
             raspi2png --stdout -h 100
         else
             scrot -t 20 -q 50 /tmp/screenshot.jpg || exit 1
             rm /tmp/screenshot.jpg
             cat /tmp/screenshot-thumb.jpg
         fi
    ;;
    *)
        echo "Usage screen.sh {on|off|state|subscribe|screenshot>}"
        exit 1
    ;;
esac

exit 0
